@@ -343,18 +343,20 @@ class StackWithId(Stack):
 
         if not isinstance(item, dict):
             raise Exception(f'{item} must be dict')
+
         if not self.exists(item.get(self.id)):
             self.stack.append(item)
             if isinstance(logger, Logger):
                 logger.debug(f'self.stack.append: {item}')
                 logger.debug(f'self.stack.size: {self.size()}')
+
+            if isinstance(logger, Logger):
+                logger.debug(f'size stack: {len(self.stack)}')
+
             return True
         else:
             raise Exception(f'{item} will be doublicate')
-
-        if isinstance(logger, Logger):
-            logger.debug(f'size stack: {len(self.stack)}')
-        return True
+            # logger.warning(f'{item} will be doublicate')
 
     def exists(self, id):
         return len(self.find(id)) > 0
@@ -376,7 +378,6 @@ class StackWithId(Stack):
 
         return res[0]
 
-
 def get_list_nums_key_dict(data):
     res = []
     if isinstance(data, dict):
