@@ -1,7 +1,7 @@
 from django.conf import settings
 
 
-def make_shedurer_tasks(func=None, when='1s', start=None, args=None, kwargs=None, name=None, repeating=True, threaded=True):
+def make_shedurer_tasks(func=None, when='1s', start=None, args=None, kwargs=None, name=None, repeating=False, threaded=True):
     from isc_common.management.commands.grop_tmp_mat_views import grop_mat_views
     from pyriodic import Scheduler, DurationJob
 
